# coding: utf-8
import pprint
import six
from enum import Enum



class ManualTaskAction:

    swagger_types = {
    
        'id': 'int',
        'label': 'dict(str, str)',
        'style': 'ManualTaskActionStyle',
        'task_type': 'int',
    }

    attribute_map = {
        'id': 'id','label': 'label','style': 'style','task_type': 'taskType',
    }

    
    _id = None
    _label = None
    _style = None
    _task_type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.label = kwargs.get('label', None)
        self.style = kwargs.get('style', None)
        self.task_type = kwargs.get('task_type', None)
        

    
    @property
    def id(self):
        """Gets the id of this ManualTaskAction.

            A unique identifier for the object.

        :return: The id of this ManualTaskAction.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ManualTaskAction.

            A unique identifier for the object.

        :param id: The id of this ManualTaskAction.
        :type: int
        """

        self._id = id
    
    @property
    def label(self):
        """Gets the label of this ManualTaskAction.

            The action's label.

        :return: The label of this ManualTaskAction.
        :rtype: dict(str, str)
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ManualTaskAction.

            The action's label.

        :param label: The label of this ManualTaskAction.
        :type: dict(str, str)
        """

        self._label = label
    
    @property
    def style(self):
        """Gets the style of this ManualTaskAction.

            The action's style.

        :return: The style of this ManualTaskAction.
        :rtype: ManualTaskActionStyle
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this ManualTaskAction.

            The action's style.

        :param style: The style of this ManualTaskAction.
        :type: ManualTaskActionStyle
        """

        self._style = style
    
    @property
    def task_type(self):
        """Gets the task_type of this ManualTaskAction.

            The type of manual tasks this action belongs to.

        :return: The task_type of this ManualTaskAction.
        :rtype: int
        """
        return self._task_type

    @task_type.setter
    def task_type(self, task_type):
        """Sets the task_type of this ManualTaskAction.

            The type of manual tasks this action belongs to.

        :param task_type: The task_type of this ManualTaskAction.
        :type: int
        """

        self._task_type = task_type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ManualTaskAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ManualTaskAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class WebhookEncryptionPublicKey:

    swagger_types = {
    
        'id': 'str',
        'public_key': 'str',
    }

    attribute_map = {
        'id': 'id','public_key': 'publicKey',
    }

    
    _id = None
    _public_key = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.public_key = kwargs.get('public_key', None)
        

    
    @property
    def id(self):
        """Gets the id of this WebhookEncryptionPublicKey.

            The ID of encryption key

        :return: The id of this WebhookEncryptionPublicKey.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookEncryptionPublicKey.

            The ID of encryption key

        :param id: The id of this WebhookEncryptionPublicKey.
        :type: str
        """

        self._id = id
    
    @property
    def public_key(self):
        """Gets the public_key of this WebhookEncryptionPublicKey.

            The BASE64 encoded public key

        :return: The public_key of this WebhookEncryptionPublicKey.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this WebhookEncryptionPublicKey.

            The BASE64 encoded public key

        :param public_key: The public_key of this WebhookEncryptionPublicKey.
        :type: str
        """

        self._public_key = public_key
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(WebhookEncryptionPublicKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, WebhookEncryptionPublicKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class RefundRecoveryBankTransaction(TransactionAwareEntity):

    swagger_types = {
    
        'bank_transaction': 'BankTransaction',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'refund': 'Refund',
        'refund_currency_amount': 'float',
        'refund_currency_value_amount': 'float',
        'space_view_id': 'int',
        'version': 'int',
    }

    attribute_map = {
        'bank_transaction': 'bankTransaction','language': 'language','line_items': 'lineItems','refund': 'refund','refund_currency_amount': 'refundCurrencyAmount','refund_currency_value_amount': 'refundCurrencyValueAmount','space_view_id': 'spaceViewId','version': 'version',
    }

    
    _bank_transaction = None
    _language = None
    _line_items = None
    _refund = None
    _refund_currency_amount = None
    _refund_currency_value_amount = None
    _space_view_id = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.bank_transaction = kwargs.get('bank_transaction', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.refund = kwargs.get('refund', None)
        self.refund_currency_amount = kwargs.get('refund_currency_amount', None)
        self.refund_currency_value_amount = kwargs.get('refund_currency_value_amount', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def bank_transaction(self):
        """Gets the bank_transaction of this RefundRecoveryBankTransaction.

            

        :return: The bank_transaction of this RefundRecoveryBankTransaction.
        :rtype: BankTransaction
        """
        return self._bank_transaction

    @bank_transaction.setter
    def bank_transaction(self, bank_transaction):
        """Sets the bank_transaction of this RefundRecoveryBankTransaction.

            

        :param bank_transaction: The bank_transaction of this RefundRecoveryBankTransaction.
        :type: BankTransaction
        """

        self._bank_transaction = bank_transaction
    
    @property
    def language(self):
        """Gets the language of this RefundRecoveryBankTransaction.

            The language that is linked to the object.

        :return: The language of this RefundRecoveryBankTransaction.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this RefundRecoveryBankTransaction.

            The language that is linked to the object.

        :param language: The language of this RefundRecoveryBankTransaction.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this RefundRecoveryBankTransaction.

            The line items contain the items which could be recovered.

        :return: The line_items of this RefundRecoveryBankTransaction.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this RefundRecoveryBankTransaction.

            The line items contain the items which could be recovered.

        :param line_items: The line_items of this RefundRecoveryBankTransaction.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def refund(self):
        """Gets the refund of this RefundRecoveryBankTransaction.

            

        :return: The refund of this RefundRecoveryBankTransaction.
        :rtype: Refund
        """
        return self._refund

    @refund.setter
    def refund(self, refund):
        """Sets the refund of this RefundRecoveryBankTransaction.

            

        :param refund: The refund of this RefundRecoveryBankTransaction.
        :type: Refund
        """

        self._refund = refund
    
    @property
    def refund_currency_amount(self):
        """Gets the refund_currency_amount of this RefundRecoveryBankTransaction.

            Specify the posting amount in the refund's currency.

        :return: The refund_currency_amount of this RefundRecoveryBankTransaction.
        :rtype: float
        """
        return self._refund_currency_amount

    @refund_currency_amount.setter
    def refund_currency_amount(self, refund_currency_amount):
        """Sets the refund_currency_amount of this RefundRecoveryBankTransaction.

            Specify the posting amount in the refund's currency.

        :param refund_currency_amount: The refund_currency_amount of this RefundRecoveryBankTransaction.
        :type: float
        """

        self._refund_currency_amount = refund_currency_amount
    
    @property
    def refund_currency_value_amount(self):
        """Gets the refund_currency_value_amount of this RefundRecoveryBankTransaction.

            

        :return: The refund_currency_value_amount of this RefundRecoveryBankTransaction.
        :rtype: float
        """
        return self._refund_currency_value_amount

    @refund_currency_value_amount.setter
    def refund_currency_value_amount(self, refund_currency_value_amount):
        """Sets the refund_currency_value_amount of this RefundRecoveryBankTransaction.

            

        :param refund_currency_value_amount: The refund_currency_value_amount of this RefundRecoveryBankTransaction.
        :type: float
        """

        self._refund_currency_value_amount = refund_currency_value_amount
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this RefundRecoveryBankTransaction.

            

        :return: The space_view_id of this RefundRecoveryBankTransaction.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this RefundRecoveryBankTransaction.

            

        :param space_view_id: The space_view_id of this RefundRecoveryBankTransaction.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def version(self):
        """Gets the version of this RefundRecoveryBankTransaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this RefundRecoveryBankTransaction.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this RefundRecoveryBankTransaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this RefundRecoveryBankTransaction.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RefundRecoveryBankTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RefundRecoveryBankTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class LegalOrganizationForm:

    swagger_types = {
    
        'country': 'str',
        'description': 'list[LocalizedString]',
        'english_description': 'str',
        'id': 'int',
        'shortcut': 'list[LocalizedString]',
    }

    attribute_map = {
        'country': 'country','description': 'description','english_description': 'englishDescription','id': 'id','shortcut': 'shortcut',
    }

    
    _country = None
    _description = None
    _english_description = None
    _id = None
    _shortcut = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.country = kwargs.get('country', None)
        self.description = kwargs.get('description', None)
        self.english_description = kwargs.get('english_description', None)
        self.id = kwargs.get('id', None)
        self.shortcut = kwargs.get('shortcut', None)
        

    
    @property
    def country(self):
        """Gets the country of this LegalOrganizationForm.

            The two-letter code of the country the legal organization form is used in (ISO 3166-1 alpha-2 format).

        :return: The country of this LegalOrganizationForm.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this LegalOrganizationForm.

            The two-letter code of the country the legal organization form is used in (ISO 3166-1 alpha-2 format).

        :param country: The country of this LegalOrganizationForm.
        :type: str
        """

        self._country = country
    
    @property
    def description(self):
        """Gets the description of this LegalOrganizationForm.

            The localized descriptions of the legal organization form.

        :return: The description of this LegalOrganizationForm.
        :rtype: list[LocalizedString]
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LegalOrganizationForm.

            The localized descriptions of the legal organization form.

        :param description: The description of this LegalOrganizationForm.
        :type: list[LocalizedString]
        """

        self._description = description
    
    @property
    def english_description(self):
        """Gets the english_description of this LegalOrganizationForm.

            The English name of the legal organization form.

        :return: The english_description of this LegalOrganizationForm.
        :rtype: str
        """
        return self._english_description

    @english_description.setter
    def english_description(self, english_description):
        """Sets the english_description of this LegalOrganizationForm.

            The English name of the legal organization form.

        :param english_description: The english_description of this LegalOrganizationForm.
        :type: str
        """

        self._english_description = english_description
    
    @property
    def id(self):
        """Gets the id of this LegalOrganizationForm.

            A unique identifier for the object.

        :return: The id of this LegalOrganizationForm.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LegalOrganizationForm.

            A unique identifier for the object.

        :param id: The id of this LegalOrganizationForm.
        :type: int
        """

        self._id = id
    
    @property
    def shortcut(self):
        """Gets the shortcut of this LegalOrganizationForm.

            The localized shortcuts of the legal organization form.

        :return: The shortcut of this LegalOrganizationForm.
        :rtype: list[LocalizedString]
        """
        return self._shortcut

    @shortcut.setter
    def shortcut(self, shortcut):
        """Sets the shortcut of this LegalOrganizationForm.

            The localized shortcuts of the legal organization form.

        :param shortcut: The shortcut of this LegalOrganizationForm.
        :type: list[LocalizedString]
        """

        self._shortcut = shortcut
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(LegalOrganizationForm, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, LegalOrganizationForm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
